@@ -1,7 +1,9 @@
 from .resnet_dec import ResNet_D_Dec, BasicBlock
 from .res_shortcut_dec import ResShortCut_D_Dec
 
-__all__ = ['res_shortcut_decoder_22']
+RES_SHORTCUT_DECODER_22 = 'res_shortcut_decoder_22'
+
+__all__ = [RES_SHORTCUT_DECODER_22]
 
 
 def _res_shortcut_D_dec(block, layers, **kwargs):
@@ -12,4 +14,4 @@ def _res_shortcut_D_dec(block, layers, **kwargs):
 def res_shortcut_decoder_22(**kwargs):
     """Constructs a resnet_encoder_14 model.
     """
-    return _res_shortcut_D_dec(BasicBlock, [2, 3, 3, 2], **kwargs)
\ No newline at end of file
+    return _res_shortcut_D_dec(BasicBlock, [2, 3, 3, 2], **kwargs)
