@@ -1,13 +1,15 @@
 import torch
 import torch.nn as nn
 
-from . import ops
 from . import decoders
 from . import encoders
+from . import ops
+from .decoders import RES_SHORTCUT_DECODER_22
+from .encoders import RES_SHORTCUT_ENCODER_29
 
 
 class Generator(nn.Module):
-    def __init__(self, encoder, decoder):
+    def __init__(self, encoder=RES_SHORTCUT_ENCODER_29, decoder=RES_SHORTCUT_DECODER_22):
 
         super(Generator, self).__init__()
 
@@ -28,8 +30,3 @@ class Generator(nn.Module):
         pred = self.decoder(embedding, mid_fea)
 
         return pred
-
-
-def get_generator(encoder, decoder):
-    generator = Generator(encoder=encoder, decoder=decoder)
-    return generator
