@@ -1,6 +1,7 @@
 import glob
 import os
 
+import cv2
 import torch
 from PIL import Image
 from skimage import io
@@ -8,7 +9,6 @@ from torch import cuda
 from torch.autograd import Variable
 from torch.utils.data import DataLoader
 from torchvision.transforms import Compose
-
 from .data_loader import RescaleT
 from .data_loader import SalObjDataset
 from .data_loader import ToTensorLab
@@ -46,11 +46,12 @@ class DataSetIter:
     def get_image_dataset(self, data_set):
         return data_set['image']
 
-    def open_image(self, index):
-        return io.imread(self.image_list[index])
+    def open_cv_image(self, index):
+        return cv2.imread(self.image_list[index])
 
     def deacidizing(self, index, mid_image):
-        src_image = self.open_image(index)
+        image_abspath = self.image_list[index]
+        src_image = io.imread(image_abspath)
 
         image_mask = mid_image.resize((src_image.shape[1], src_image.shape[0]), resample=Image.BILINEAR)
 
